# Styles and helper functions for matplotlib

The latex styles use lualatex as a backend.

## Installation

This package was developed and used on Linux.
[It is available on the PyPI respository]().
It can be installed by running
```
pip install matplotlibstyles
```
If you do not have root access and it does not automatically default to installing locally, the `--user` flag may be used.

For more information on building and installing python packages, see the documentation from the [Python Packaging Authority](https://packaging.python.org/en/latest/).
